Hidden Items
::::::::::::::::::::::::::::::::

.. toctree::
   :hidden:
   :maxdepth: 2

   class-exp/class-intro-classes.rst
   class-exp/class-intro.rst
   class-exp/class-pnd.rst
   class-exp/class-post.rst
   class-exp/class-postsurvey.rst
   class-exp/class-presurvey.rst
   class-exp/class-pretest.rst
   class-exp/class-pwd.rst
   class-exp/class-study-intro.rst
   class-exp/class-timed-intro.rst
   dclass-exp/dclass-intro-classes.rst
   dclass-exp/dclass-intro.rst
   dclass-exp/dclass-pnd.rst
   dclass-exp/dclass-post.rst
   dclass-exp/dclass-postsurvey.rst
   dclass-exp/dclass-presurvey.rst
   dclass-exp/dclass-pretest.rst
   dclass-exp/dclass-pwd.rst
   dclass-exp/dclass-study-intro.rst
   dclass-exp/dclass-timed-intro.rst
   python-swap/ps-intro.rst
   python-swap/ps-parsons.rst
   python-swap/ps-post.rst
   python-swap/ps-postsurvey.rst
   python-swap/ps-presurvey.rst
   python-swap/ps-study-intro.rst
